#
# spec file for package libinfinity
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 0.7
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           libinfinity
Version:        0.7.2
Release:        4.14
Summary:        Implementation of the Infinote collaborative editing protocol
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://gobby.github.io/
Source0:        https://github.com/gobby/libinfinity/releases/download/%{version}/libinfinity-%{version}.tar.gz
Source1:        infinoted.service
Source2:        infinoted.sysconfig
Source3:        infinoted.conf
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch0:         infinoted-add-conf-subdir.patch
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  gtk-doc
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(gio-2.0) >= 2.40
BuildRequires:  pkgconfig(glib-2.0) >= 2.38
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.38
BuildRequires:  pkgconfig(gnutls) >= 2.12.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.38
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10.0
BuildRequires:  pkgconfig(libdaemon)
BuildRequires:  pkgconfig(libgsasl) >= 0.2.21
BuildRequires:  pkgconfig(libxml-2.0)

%description
libinfinity is an implementation of the Infinote protocol written in
GObject-based C. Infinote is a protocol for collaborative editing
multiple documents and is portable to both Windows and Unix-like
platforms.

%package -n libinfinity-0_7-0
Summary:        Implementation of the Infinote collaborative editing protocol
Group:          System/Libraries
# Needed to make lang package installable
Provides:       %{name} = %{version}-%{release}
Conflicts:      libinfinity-1_0-0

%description -n libinfinity-0_7-0
libinfinity is an implementation of the Infinote protocol written in
GObject-based C. Infinote is a protocol for collaborative editing
multiple documents and is portable to both Windows and Unix-like
platforms.

%package devel
Summary:        Implementation of the Infinote collaborative editing protocol
Group:          Development/Libraries/GNOME
Requires:       libgnutls-devel
Requires:       libgsasl-devel
Requires:       libinfinity-0_7-0 = %{version}-%{release}
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gtk+-2.0)
Requires:       pkgconfig(libxml-2.0)

%description devel
libinfinity is an implementation of the Infinote protocol written in
GObject-based C. Infinote is a protocol for collaborative editing
multiple documents and is portable to both Windows and Unix-like
platforms.

%package -n infinoted
Summary:        Server for Collaborative Document Edition
Group:          Development/Libraries/GNOME

%description -n infinoted
Infinoted is a server for collaborative edition of documents via the
Infinote protocol. It is typically used with Gobby as a client.

%lang_package

%prep
%autosetup -p1

%build
# -fno-strict-aliasing added 2009-05-07. Need for 0.3.0 -- vuntz
CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
      --disable-static \
      --with-systemd \
      --with-gio
%make_build

%install
%make_install
%find_lang %{name}-%{_version}
find %{buildroot} -type f -name "*.la" -delete -print
# Install systemd service file
install -d -m 0755 %{buildroot}%{_unitdir}
install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/infinoted.service
install -d -m 0755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcinfinoted
# Create sysconfig data
install -D -m 0644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.infinoted
install -d -m 0755 %{buildroot}/srv/infinoted
# Create infinoted default configuration
install -d -m 0755 %{buildroot}%{_sysconfdir}/xdg/infinoted
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/xdg/infinoted/infinoted.conf
# Note: the infinoted binary is versioned, and we could use update-alternatives
# to provide it also non-versioned. However, the init.d, sysconfig and xdg
# config files are not versioned, and it will actually be bad for the user to
# have them versioned (potential loss of configuration, for example). So let's
# just unversion the binary and man page
mv %{buildroot}%{_bindir}/infinoted-%{_version} %{buildroot}%{_bindir}/infinoted
mv %{buildroot}%{_mandir}/man1/infinoted-%{_version}.1 %{buildroot}%{_mandir}/man1/infinoted.1
%fdupes %{buildroot}

%post   -n libinfinity-0_7-0 -p /sbin/ldconfig
%postun -n libinfinity-0_7-0 -p /sbin/ldconfig

%pre -n infinoted
%service_add_pre infinoted.service

%post -n infinoted
%{fillup_only -n infinoted}
%service_add_post infinoted.service

%preun -n infinoted
%stop_on_removal infinoted
%service_del_preun infinoted.service

%postun -n infinoted
%service_del_postun infinoted.service

%files -n libinfinity-0_7-0
%license COPYING
%{_libdir}/libinf*.so.*

%files devel
%{_includedir}/libinf*
%{_libdir}/libinf*.so
%{_libdir}/pkgconfig/libinf*.pc
%{_datadir}/gtk-doc/html/*

%files -n infinoted
%doc AUTHORS ChangeLog NEWS TODO
%{_bindir}/infinoted
%{_mandir}/man1/infinoted.1%{?ext_man}
%{_libdir}/infinoted-%{_version}
# default configuration
%dir %{_sysconfdir}/xdg/infinoted
%config(noreplace) %{_sysconfdir}/xdg/infinoted/infinoted.conf
%{_sbindir}/rcinfinoted
# sysconfig data
%{_fillupdir}/sysconfig.infinoted
%dir /srv/infinoted
%{_unitdir}/infinoted.service
# Only needed for the test applications, it seems
%exclude %{_datadir}/icons/hicolor/*/apps/infinote.*

%files lang -f %{name}-%{_version}.lang

%changelog
* Thu May  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libinfinity-1_0-0 requires from infinoted package: the dep
  is wrong since the library package was changed to correctly
  follow SLPP. Additionally, the library is dependency is
  auto-detected.
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint error "libinfinity-1_0-0.x86_64: E:
  shlib-policy-name-error SONAME: libinfgtk-0.7.so.0, expected
  package suffix: 0_7-0"
- Move documentation to subpackage with main applications
* Mon Oct  4 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * infinoted.service
* Mon May 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.7.2
  + Fix user table iteration order to be deterministic, possibly
    fixing on out-of-sync bug.
  + Fix a possible crash when running g-ir-scanner.
  + infinoted: Add support for notifying systemd when the service
    is running.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Nov 15 2018 Dominique Leuenberger <dimstar@opensuse.org>
- Convert sysv init script to systemd service (boo#1116016)
- Pass --with-systemd to configure: enable proper systemd
  integration.
- Automatic cleanup using spec-cleaner.
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Mar 17 2017 jengelh@inai.de
- Drop useless --with-pic, it is for (unbuilt) static libs.
* Wed Mar  8 2017 zaitor@opensuse.org
- Update to version 0.7.1:
  + Fix a possible crash when uploading a document to the infinoted
    server.
  + Fix two instances of possible format string injection.
- Changes from version 0.7.0:
  + Infinoted:
  - Allow to listen on a specific interface instead of all
    interfaces.
  - Add a dbus plugin which allows some interaction with reading
    and modifying the directory tree.
  + Removed support for GTK+ 2.x. libinfinity-0.7 can only be built
    against GTK+ 3.x.
  + Generate gobject-introspection repositories, allowing
    libinfinity to be used from higher-level programming languages
    such as Python.
  + Enable TCP keepalives on all connections to prevent inactive
    connections from being dropped by a firewall, and to allow
    quicker detection of an actual disconnect.
- Add explicit pkgconfig(gobject-2.0), pkgconfig(gmodule-2.0) and
  pkgconfig(gio-2.0): align with what configure looks for.
- Drop conditional pkgconfig(gtk+-2.0) BuildRequires and stop
  passing --without-gtk3 and --with-gtk3 to configure: No longer
  makes any sense, following upstreams changes.
- Add --with-gio configure call, follow what upstream checks for.
- Bump define version to 0.7.
- Drop postun %%insserv_cleanup call, no longer needed.
* Wed Dec 30 2015 netzheimer@yahoo.de
- Update to version 0.6.7:
  + Fix crash when library is linked against glib 2.46 or newer.
  + Fixes potential crashes in some other uncommon situations.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 0.6.6:
  + Fix certificates being only verified for expiration and other
    criteria such as weak algorithms if the CA is not trusted.
  + Fix some assertion failures and inconsistencies in
    InfTextFixlineBuffer.
  + Fix a client-side crash when the server shuts down ordinarily
    while still connected.
* Tue Feb  3 2015 dimstar@opensuse.org
- Update to version 0.6.5:
  + Fix memory corruption in InfTextFixlineBuffer.
  + infinoted: Fix error message in server log when a client
    certificate is not trusted.
  + Fix various crashes related to sending data to already closed
    connections.
  + Build fix when res_query is provided by libc, not libresolv,
    such as on FreeBSD.
- Changes from version 0.6.4:
  + Build fixes for Mac OS X.
* Sat Oct 11 2014 zaitor@opensuse.org
- Update to version 0.6.3:
  + infinoted:
  - Fix a possible timing attack on the server password.
  - Use mode 0777 instead of 0700 when creating directories in
    the directory-sync plugin.
  + Write certificates not seen before into the known hosts file.
* Thu Sep 18 2014 dimstar@opensuse.org
- Update to version 0.6.2:
  + Fix accounts being deleted when a plugin overrides the default
    account storage.
  + The infinoted manual page has been corrected for the syntax of
    the --plugins option.
  + A crash has been fixed when a connection is closed for which
    the the certificate dialog was shown.
- Changes from version 0.6.1:
  + Explicitly link against libresolv on unix-based systems, to
    avoid a possible build failure.
- Changes from version 0.6.0:
  + infinoted: Introduced a plugin infrastructure, and ported some
    of the previous functionality to plugins.
  + infinoted: Add a plugin for client authentication with
    certificates.
  + Add a system for user management and access control lists
    (ACLs).
  + Change certificate checker to a trust-on-first-use (SSH-like)
    mechanism when the signer cannot be verified.
  + Code refactorings, and many new interfaces and APIs.
- Move BuildRequires, that are duplicated between GTK3 and GTK2
  variant out of the if block.
- Rebase infinoted-add-conf-subdir.patch.
- Drop libinfinity-includes.patch: fixed upstream.
* Sun Jan 19 2014 zaitor@opensuse.org
- Update to version 0.5.5:
  + Fix a crash in infinoted when nmap scans the infinote port.
* Thu Aug 22 2013 dimstar@opensuse.org
- Re-download the tarball: seems upstream re-released it with a
  minor fix.
* Sat Jul 20 2013 vuntz@opensuse.org
- Update to version 0.5.4:
  + Fix crashes that can happen when the connection goes down at
    unexpected moments.
  + Fix a crash when when drawing remote cursors or selections and
    the initial document has not yet been fully transmitted.
  + Fix a possible crash when undoing or redoing many operations in
    a row.
* Wed Oct 31 2012 dimstar@opensuse.org
- Update to version 0.5.3:
  + Fix a crash when a connection goes down at the moment
    libinfinity is trying to send data.
  + Fix possible undefined behavior at type registration.
- Add libinfiniti-includes.patch: Fix missing header includes.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 0.5.2:
  + Fix a crash when a server certificate does not have a hostname
    set
  + Fix a crash when the remote side sends invalid UTF-8
  + Fix compilation with glib >= 2.31
- Drop libinfinity-glib-2.31.patch: fixed upstream.
* Wed Dec 14 2011 jangerrit@weiler-marker.com
- Add pam-devel BuildRequires to build with pam support.
* Wed Nov 30 2011 dimstar@opensuse.org
- Add libinfinity-glib-2.31.patch: Fix build with glib 2.31.
* Tue Aug  2 2011 dimstar@opensuse.org
- Update to version 0.5.1:
  + infinoted:
  - Update directory sync settings on config reload
  - Fix a crash when directory sync was enabled
  + Fix the build on Mac OS X
  + Disallow node names containing non-printable or only space
    characters
  + Fixed a reference leak in infd_directory_add_note()
  + Fixed a crash in infd_directory_iter_get_session()
* Fri May 27 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires if we target a gtk3
  build:
  + Old ones: glib2-devel, gnutls-devel, libavahi-devel,
    libdaemon-devel, libgsasl-devel, libxml2-devel.
  + New ones: avahi-client, glib-2.0, gnutls, libdaemon, libgsasl,
    libxml-2.0.
* Thu Apr 28 2011 dimstar@opensuse.org
- Use favor_gtk2 to switch between gtk2 and gtk3 builds.
- For gtk3 build, add pkgconfig(gtk+-3.0) BuildRequires.
- Pass -with-gtk3/--without-gtk3 based on favor_gtk2 to configure.
* Thu Apr 21 2011 dimstar@opensuse.org
- Update to version 0.5.0:
  + infinoted: Added the --pam-server, --allow-user and
  - -allow-group command line options.
  + Show cursor and selection of remote users in the own textview
    and the scrollbar.
  + Add optional support for GTK+ 3.
  + Provide asynchronous SASL authentication.
- Rebase infinoted-add-conf-subdir.patch.
* Fri Nov 26 2010 dimstar@opensuse.org
- Update to version 0.4.2:
  + infinoted: Fixed a bug when infinoted did not launch in
    daemonized mode when the global PID file directory did not
    exist.
  + Fixed a crash which could occur in high latency concurrent
    situations.
  + Fixed a possible crash when multiple connections time out at
    the same time.
  + Fixed a crash when receiving an unexpected XML opening and
    ending tag on the top-level.
- Change -lang package Requires to Recommends, as it's not a strict
  runtime requirement.
* Thu Feb 18 2010 vuntz@opensuse.org
- Update to version 0.4.1:
  + infinoted: Avoid a runtime warning when infinoted can not be
    started.
  + Fixed a crash in undo grouping when undoing a large number of
    requests.
  + Fixed a crash when showing closed connections in a
    InfGtkBrowserView.
  + Fixed expander arrows on non-expandable columns in
    InfGtkBrowserView.
  + Fixed a crash when closing an XML connection still in use by
    a session.
  + Introduced new API.
* Sun Dec 20 2009 vuntz@opensuse.org
- Update to version 0.4.0:
  + infinoted: Added the --password, --sync-directory,
  - -sync-interval, --daemonize and --kill-daemon command line
    options.
  + infinoted: Reload configuration file at runtime on SIGHUP
  + Added an IRC-like chat, driven by InfChatSession.
  + Added functionality to group undo requests to be undone in a
    single step.
- Rebase infinoted-add-conf-subdir.patch to apply without fuzz.
- Add libdaemon-devel BuildRequires.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 0.3.1:
  + Avoid a crash when synchronizing a zero-length delete operation
  + Fix sporadic disconnections on Windows
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Jun 10 2009 dmueller@suse.de
- Move Requires for lang package to libinfinity-1_0-0.
* Thu May  7 2009 vuntz@novell.com
- Review packages.
- Remove unneeded BuildRequires: gcc-c++, libsigc++2-devel,
  pkg-config, gmp-devel, cairo-devel, libxml++-devel,
  libuuid-devel.
- Remove AutoReqProv: it's default now.
- Update the Requires of the devel package.
- Merge doc package with devel package.
- Build with -fno-strict-aliasing: there's a warning requiring it.
- Do not keep the versioned binary.
- Do not ship the icons: they don't appear to be needed.
* Thu Apr 30 2009 opensuse@sukimashita.com
- Update to 0.3.0:
  * infinoted: Added the --certificate-chain command line option.
  * Support rejecting a subscription on the client side, for example
    when the client does not support the communication method.
  * Made libinfinity parallel-installable with future versions.
* Sat Jan 10 2009 opensuse@sukimashita.com
- Update to 0.2.0:
  * infinoted records sessions to ~/.infinoted-records
  * Added proper modification tracking, and an autosave feature for
    infinoted.
  * Implemented InfStandaloneIo on Windows, making infinoted run on
    Windows
  * Refactored connection manager, introducing InfCommunication API for
    high-level network handling. This breaks protocol compatibility with
    libinfinity 0.1.x.
- Since 0.1.2:
  * Fixed required dependencies in pkg-config files
  * Improved error message when the remote host does not send XMPP
  * Fixed a crash when compiling with -O2 or above
  * Fixed a few memory leaks
  * Fixed build with cairo 1.4 (#393)
* Thu Dec  4 2008 opensuse@sukimashita.com
- Update to git version 20081204
  * Implemented auto-saver feature for infinoted
  * Install conf file to /etc/xdg to correctly recognize global configuration
* Sun Nov  9 2008 opensuse@sukimashita.com
- Update to 0.1.1:
  * Made libinfinity properly relocatable on Windows
  * Fixed the documentation build when avahi is disabled
  * Fixed a segfault when showing the file list
  * Fixed pasting a lot amount of text
  * Fixed connection to server with much history
* Thu Oct 23 2008 opensuse@sukimashita.com
- Initial package created
